@@ -20,7 +20,7 @@ package Sidef::Module::Func {
 
         my @args = (
                     @arg
-                    ? (map { index(ref($_), 'Sidef::') == 0 ? $_->get_value : $_ } @arg)
+                    ? (map { (index(ref($_), 'Sidef::') == 0) ? $_->get_value : $_ } @arg)
                     : ()
                    );
 
@@ -34,7 +34,7 @@ package Sidef::Module::Func {
 
         $multi_values // return;
 
-        @results = map { Sidef::Perl::Perl->to_sidef($_) } @results;
+        @results = map { Sidef::Types::Perl::Perl->to_sidef($_) } @results;
 
         if (@results > 1) {
             return ($multi_values ? @results : Sidef::Types::Array::Array->new(\@results));
