@@ -15,12 +15,14 @@ use lib qw(../../lib);
 # Load the Sidef main module
 use Sidef;
 
-# Initialize a new parser and a new deparser
-my $parser = Sidef::Parser->new();
-my $deparser = Sidef::Deparse::Perl->new();
+my $sidef = Sidef->new(
+                       name       => 'test',    # program name
+                       opt        => {},        # command-line options
+                       parser_opt => {},        # parser options
+                      );
 
-# Parse some code and store the returned parse-tree
-my $struct = $parser->parse_script(code => \<<'SIDEF_CODE');
+# Execute arbitrary Sidef code
+my $num = $sidef->execute_code(<<'SIDEF_CODE');
 
 func fib(n) {
     n > 1 ? (__FUNC__(n-1) + __FUNC__(n-2)) : n;
@@ -30,9 +32,6 @@ fib(12);
 
 SIDEF_CODE
 
-# Generate Perl code and evaluate it
-my $num = eval $deparser->deparse($struct);
-
 # Output the result
 say $num;
 
